@@ -709,4 +709,4 @@ if (name.indexOf("captureLooping") >= 0) info = (this.vwr.am.animationReplayMode
 return (info == null ? text : text.substring(0, pt) + " (" + info + ")");
 }, "~S,~S");
 });
-;//5.0.1-v7 Mon Jul 21 08:59:16 CDT 2025
+;//5.0.1-v7 Sun Nov 02 22:55:28 CST 2025
