@@ -1,3 +1,3 @@
 Clazz.declarePackage("JSV.api");
 Clazz.declareInterface(JSV.api, "SourceReader");
-;//5.0.1-v7 Mon Jul 21 08:59:16 CDT 2025
+;//5.0.1-v7 Tue Sep 16 15:25:55 CDT 2025
