@@ -97,9 +97,9 @@ function(){
 return "[" + this.getInfo() + "]";
 });
 c$.fontkeyCount = 1;
-c$.fontkeys =  Clazz.newIntArray (/*org.eclipse.jdt.core.dom.SimpleName*/8, 0);
+c$.fontkeys =  Clazz.newIntArray (8, 0);
 c$.font3ds =  new Array(8);
 c$.fontFaces =  Clazz.newArray(-1, ["SansSerif", "Serif", "Monospaced", ""]);
 c$.fontStyles =  Clazz.newArray(-1, ["Plain", "Bold", "Italic", "BoldItalic"]);
 });
-;//5.0.1-v4 Wed Dec 11 08:23:48 CST 2024
+;//5.0.1-v7 Tue Sep 16 15:25:55 CDT 2025
